"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserValidationProvider = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const core_2 = require("@sourceloop/core");
const keys_1 = require("./keys");
let UserValidationProvider = class UserValidationProvider {
    constructor(logger, googleAuthenticationProvider, keycloakAuthenticationProvider, defaultAuthneticationProvider) {
        this.logger = logger;
        this.googleAuthenticationProvider = googleAuthenticationProvider;
        this.keycloakAuthenticationProvider = keycloakAuthenticationProvider;
        this.defaultAuthneticationProvider = defaultAuthneticationProvider;
    }
    value() {
        return async (req, payload, signUpProvider, token) => this.isAuthenticated(payload, signUpProvider, token);
    }
    async isAuthenticated(payload, signUpProvider, token) {
        let isAuthenticated = true;
        const accessToken = payload.refreshPayload.externalAuthToken;
        switch (signUpProvider) {
            case "google" /* SignUpProviderKey.Google */:
                isAuthenticated = await this.googleAuthenticationProvider(accessToken);
                break;
            case "keycloak" /* SignUpProviderKey.Keycloak */:
                isAuthenticated =
                    await this.keycloakAuthenticationProvider(accessToken);
                break;
            default:
                isAuthenticated = await this.defaultAuthneticationProvider(accessToken);
            // If none of the cases apply, the default case will set isAuthenticated to true
        }
        return isAuthenticated;
    }
};
exports.UserValidationProvider = UserValidationProvider;
exports.UserValidationProvider = UserValidationProvider = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, (0, core_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.UserValidationServiceBindings.GOOGLE_AUTHENTICATION)),
    tslib_1.__param(2, (0, core_1.inject)(keys_1.UserValidationServiceBindings.KEYCLOAK_AUTHENTICATION)),
    tslib_1.__param(3, (0, core_1.inject)(keys_1.UserValidationServiceBindings.DEFAULT_AUTHENTICATION)),
    tslib_1.__metadata("design:paramtypes", [Object, Function, Function, Function])
], UserValidationProvider);
//# sourceMappingURL=user-validation.provider.js.map